<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>DecoderArchiveFactory</name>
    <message>
        <location filename="../decoderarchivefactory.cpp" line="39"/>
        <source>Archive Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderarchivefactory.cpp" line="41"/>
        <source>Archives</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderarchivefactory.cpp" line="168"/>
        <source>About Archive Reader Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderarchivefactory.cpp" line="169"/>
        <source>Qmmp Archive Reader Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderarchivefactory.cpp" line="170"/>
        <source>Compiled against %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderarchivefactory.cpp" line="171"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Написана от Илия Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
